# 🇫🇷 Français

## À propos de Sinamet

Sinamet est une bibliothèque Python spécialisée pour l'analyse des flux et stocks
territorialisés\*. Sinamet prend en charge la gestion d'une
base de données à travers un modèle de données spécifique. À travers ce modèle,
il est possible de structurer des données sur différentes thématiques,
tant qu'elles décrivent des flux territorialisés, par exemple :

 * Des statistiques sur le transport de marchandises,
 * Des déplacements domicile-travail,
 * Des factures d’énergie et d'eau d'un patrimoine bâti,
 * Des commandes d'un établissement de restauration collective,
 * Des données sur la collecte de déchets,
 * Et plein d'autres !

Sinamet embarque les fonctionnalités pour faciliter la navigation dans ces données :
organiser des hiérarchies d'objets, récupérer des flux ou des stocks associés
à un territoire ou un acteur, convertir des unités ou des nomenclatures,
suivre la temporalité et la source des données, ...

\*On parle également d'étudier le "métabolisme territorial".
Sinamet est d'ailleurs l'acronyme de "Système d'Information pour l'ANalyse du
MÉtabolisme des Territoires"

## Documentation

Consultez la documentation en ligne: [https://docs.sinamet.tech](https://docs.sinamet.tech)

## Contact

Des questions à propos de la bibliothèque ? Vous souhaitez être formé à
l'utilisation de l'outil ou vous souhaitez mettre un observatoire des flux sur
votre territoire ? Contactez l'équipe de développement : libadmin@sinamet.tech

## Credit

Sinamet est une bibliothèque développée par [Dynartio](https://dynartio.com),
initiée grâce au financement de l'[ADEME](https://ademe.fr) et le soutien du
[Laboratoire LIVE (University or Strasbourg/CNRS)](https://live.unistra.fr)
et diffusée en Open Source grâce au soutien de la
[Nouvelle-Aquitaine Region](https://nouvelle-aquitaine.fr).

# 🇬🇧 English

## About Sinamet

Sinamet is a Python library specialized in the analysis of territorialized
flows and stocks\*. Sinamet supports database management through a specific data
model. Using this model, it is possible to structure data of different themes,
as long as they describe territorialized flows, for example:

 * Freight transport statistics,
 * Commuting statistics,
 * Energy and water bill for a building,
 * Orders from a catering establishment,
 * Waste collection data,
 * And many more!

Sinamet includes functions to facilitate data navigation: organize object
hierarchies, retrieve flows or stocks associated with a territory or a player,
convert units or nomenclatures, track the temporality and source of data, etc.

\*We also talk about studying "territorial metabolism". Sinamet stands for
"Système d'Information pour l'ANalyse du MÉtabolisme des Territoires"

## Documentation

View online documentation: [https://docs.sinamet.tech](https://docs.sinamet.tech)

## Contact

Questions about the library ? Would you like to be trained to use the tool,
or would you like to set up an observatory of flows in your area ?
Contact the development team: libadmin@sinamet.tech

## Credit

Sinamet is a library developed by [Dynartio](https://dynartio.com), initiated
thanks to funding from [ADEME](https://ademe.fr) and supports from
[Laboratoire LIVE (University or Strasbourg/CNRS)](https://live.unistra.fr), and
released as Open Source thanks to support from the
[Nouvelle-Aquitaine Region](https://nouvelle-aquitaine.fr).
